pywurfl.RootDevice

Package pywurfl :: Class RootDevice |
[hide private]
[frames] | no frames]

# Class RootDevice

source code

    object --+
             |
            RootDevice

pywurfl Root Device base class.

All classes created by pywurfl are at root a subclass of this class.

Instance Methods | [hide private]
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`